translate.misc.ourdom.Element

Package translate :: Package misc :: Module ourdom :: Class Element |
[hide private]
[frames] | no frames]

# Class Element

source code

Instance Methods | [hide private]
yieldElementsByTagName(self, name) | source code
searchElementsByTagName(self, name, onlysearch) | source code
writexml(self, writer, indent, addindent, newl) | source code
Inherited from `xml.dom.minidom.Element`: `__init__`, `__repr__`, `getAttribute`, `getAttributeNS`, `getAttributeNode`, `getAttributeNodeNS`, `getElementsByTagName`, `getElementsByTagNameNS`, `hasAttribute`, `hasAttributeNS`, `hasAttributes`, `removeAttribute`, `removeAttributeNS`, `removeAttributeNode`, `removeAttributeNodeNS`, `setAttribute`, `setAttributeNS`, `setAttributeNode`, `setAttributeNodeNS`, `setIdAttribute`, `setIdAttributeNS`, `setIdAttributeNode`, `unlink` Inherited from `xml.dom.minidom.Element` (private): `_get_attributes`, `_get_localName`, `_get_tagName` Inherited from `xml.dom.minidom.Node`: `__nonzero__`, `appendChild`, `cloneNode`, `getInterface`, `getUserData`, `hasChildNodes`, `insertBefore`, `isSameNode`, `isSupported`, `normalize`, `removeChild`, `replaceChild`, `setUserData`, `toprettyxml`, `toxml` Inherited from `xml.dom.minidom.Node` (private): `_call_user_data_handler`, `_get_childNodes`, `_get_firstChild`, `_get_lastChild`

Class Variables | [hide private]
Inherited from `xml.dom.minidom.Element`: `nodeType`, `nodeValue`, `schemaType` Inherited from `xml.dom.minidom.Element` (private): `_child_node_types`, `_magic_id_nodes` Inherited from `xml.dom.minidom.Node`: `namespaceURI`, `nextSibling`, `ownerDocument`, `parentNode`, `prefix`, `previousSibling` Inherited from `xml.dom.Node`: `ATTRIBUTE_NODE`, `CDATA_SECTION_NODE`, `COMMENT_NODE`, `DOCUMENT_FRAGMENT_NODE`, `DOCUMENT_NODE`, `DOCUMENT_TYPE_NODE`, `ELEMENT_NODE`, `ENTITY_NODE`, `ENTITY_REFERENCE_NODE`, `NOTATION_NODE`, `PROCESSING_INSTRUCTION_NODE`, `TEXT_NODE`

Properties | [hide private]
Inherited from `xml.dom.minidom.Element`: `attributes`, `localName` Inherited from `xml.dom.minidom.Node`: `firstChild`, `lastChild`

Method Details | [hide private]

### writexml(self, writer, indent, addindent, newl) | source code
Overrides: xml.dom.minidom.Element.writexml